pub struct LineDashPattern {
pub offset: u16,
pub dashes: [u16; 2],
}Expand description
ISO 32000-1:2008 8.4.3.6
The line dash pattern shall control the pattern of dashes and gaps used to stroke paths.
Fields
offset: u16The dash phase shall specify the distance into the dash pattern at which to start the dash.
dashes: [u16; 2]The dash array’s elements shall be numbers that specify the lengths of alternating dashes and gaps; the numbers shall be nonnegative and not all zero.