pub struct Pdf {
pub alloc: Ref,
pub pdf: Pdf,
pub pages: Vec<Page>,
pub fonts: Vec<Ref>,
pub metadata: Metadata,
/* private fields */
}Fields
alloc: Refpdf: Pdfpages: Vec<Page>fonts: Vec<Ref>metadata: MetadataImplementations
Sourceimpl Pdf
impl Pdf
pub fn new(metadata: Metadata) -> Self
pub fn alloc(&mut self) -> Ref
pub fn add_page(&mut self, size: (f32, f32)) -> Location
Sourcepub fn add_element(&mut self, page_size: (f32, f32), element: impl Element)
pub fn add_element(&mut self, page_size: (f32, f32), element: impl Element)
Add an element to the PDF. A new page with the given size is added initially and additional pages of the same size are added when the element requests them during drawing.
Sourcepub fn add_element_with_text_pieces_cache(
&mut self,
page_size: (f32, f32),
text_pieces_cache: &TextPiecesCache,
element: impl Element,
)
pub fn add_element_with_text_pieces_cache( &mut self, page_size: (f32, f32), text_pieces_cache: &TextPiecesCache, element: impl Element, )
The same as Pdf::add_element, but with a TextPiecesCache parameter. This is useful when adding multiple elements to a PDF that share some fonts and text.
pub fn finish(self) -> Vec<u8> ⓘ